
local type = type
local floor = math.floor


local function fold(f)
	local function _folder(x, y, ...)
		if y == nil then
			return x
		else
			return _folder(f(x,y), ...)
		end
	end
	return _folder
end

local function unfold(f,e)
	local function _unfolder(x, ...)
		local x, y = f(x)
		if x == e then
			return y, ...
		else
			return _unfolder(x, y, ...)
		end
	end
	return function(x) return _unfolder(x) end
end


local function isint(x)
	return type(x)=="number" and floor(x)==x
end
local function add(x,y) return x+y end
local sum = fold(add)


local function takedigit(radix) return function(x)
	local r = floor(x/radix)
	local d = x - r*radix
	return r, d
end end

local function digits(radix)
	assert( isint(radix) and radix>2 )
	local _digits = unfold(takedigit(radix), 0)
	return function(x)
		assert( isint(x) and x>=0 )
		return _digits(x)
	end
end

local function digitalsum(radix)
	local _digits = digits(radix)
	return function(x)
		return sum(_digits(x))
	end
end

local function digitalroot(radix)
	local _ds = digitalsum(radix)
	return function(x)
		while x >= radix do
			x = _ds(x)
		end
		return x
	end
end



-- cli for showcase --

local radix, number = ...
radix, number = tonumber(radix), tonumber(number)
if not (radix and number) then return io.stderr:write[[
args: <radix> <number>
cli input & output is all base-10.
]] end

io.write(tostring(digitalroot(radix)(number)))
io.write("\n")
